/**
 * Copyright (C) 2008 Felipe Contreras
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02111-1301  USA
 */

#ifndef PECAN_CONFIG_H
#define PECAN_CONFIG_H

#define PACKAGE_NAME "msn-pecan"
#define PURPLE_PLUGINS

#define MSN_BUF_LEN 8192
#define PECAN_MAX_MESSAGE_LENGTH 1564

#endif /* PECAN_CONFIG_H */
